contexttools.get_key_signature_marks_attached_to_component
==========================================================

.. autofunction:: abjad.tools.contexttools.get_key_signature_marks_attached_to_component.get_key_signature_marks_attached_to_component
